aboutsummaryrefslogtreecommitdiffhomepage
path: root/tools
diff options
context:
space:
mode:
authorGravatar jcgregorio <jcgregorio@google.com>2016-02-03 08:31:07 -0800
committerGravatar Commit bot <commit-bot@chromium.org>2016-02-03 08:31:07 -0800
commitbd9dabdb3cbd81381b31f3bded72593da0b3e994 (patch)
treeda6491db043734d405f9855cf81ef5c876390da5 /tools
parent1059b1fc9f8711592a81836512850d123d75146d (diff)
Revert of Test CodecImageGenerator on GPU bots (patchset #1 id:1 of https://codereview.chromium.org/1663453002/ )
Reason for revert: Failures: D/skia ( 3581): gpu image gen frame_larger_than_image.gif: Could not create a surface. D/skia ( 3581): gpu image gen offsets_too_large.gif: Could not create a surface. D/skia ( 3581): gpu image gen PANO_20121023_214540.jpg: Could not create a surface. D/skia ( 3581): gpu image gen interlaced1.png: Could not create a surface. D/skia ( 3581): gpu image gen interlaced2.png: Could not create a surface. D/skia ( 3581): gpu image gen interlaced3.png: Could not create a surface. D/skia ( 3581): gpu image gen Canon_5D2.dng: Could not create a surface. D/skia ( 3581): gpu image gen Fuji_X20.dng: Could not create a surface. D/skia ( 3581): gpu image gen HTC.dng: Could not create a surface. D/skia ( 3581): gpu image gen lg_g4_iso_800.dng: Could not create a surface. D/skia ( 3581): gpu image gen Canon_G7X.CR2: Could not create a surface. D/skia ( 3581): gpu image gen Pentax_K5.DNG: Could not create a surface. D/skia ( 3581): gpu image gen Nikon_1AW1.NEF: Could not create a surface. D/skia ( 3581): gpu image gen Nikon_1J4.NEF: Could not create a surface. D/skia ( 3581): gpu image gen Nikon_P330.NRW: Could not create a surface. D/skia ( 3581): gpu image gen Olympus_E-PL3.ORF: Could not create a surface. D/skia ( 3581): gpu image gen Olympus_PL7.ORF: Could not create a surface. D/skia ( 3581): gpu image gen Pentax_K5.PEF: Could not create a surface. D/skia ( 3581): gpu image gen Samsung_NX3000.SRW: Could not create a surface. Original issue's description: > Test CodecImageGenerator on GPU bots > > In crrev.com/1549473003, CodecImageGenerator implemented getYUV8Planes, > so that we can test on a GPU bot. Update the arguments to DM so that > we run CodecImageGenerator on GPU bots. > GOLD_TRYBOT_URL= https://gold.skia.org/search2?unt=true&query=source_type%3Dgm&master=false&issue=1663453002 > > Committed: https://skia.googlesource.com/skia/+/c9715406c4c9c995e5661a4ea2188fb8643845c0 TBR=msarett@google.com,scroggo@google.com # Skipping CQ checks because original CL landed less than 1 days ago. NOPRESUBMIT=true NOTREECHECKS=true NOTRY=true Review URL: https://codereview.chromium.org/1663143002
Diffstat (limited to 'tools')
-rw-r--r--tools/dm_flags.json7
-rwxr-xr-xtools/dm_flags.py8
2 files changed, 6 insertions, 9 deletions
diff --git a/tools/dm_flags.json b/tools/dm_flags.json
index 87d09013f0..4e1c612aa6 100644
--- a/tools/dm_flags.json
+++ b/tools/dm_flags.json
@@ -232,7 +232,6 @@
"--src",
"tests",
"gm",
- "image",
"--blacklist",
"serialize-8888",
"gm",
@@ -435,7 +434,6 @@
"--src",
"tests",
"gm",
- "image",
"--threads",
"0",
"--blacklist",
@@ -638,7 +636,6 @@
"--src",
"tests",
"gm",
- "image",
"--threads",
"0",
"--blacklist",
@@ -845,7 +842,6 @@
"--src",
"tests",
"gm",
- "image",
"--blacklist",
"serialize-8888",
"gm",
@@ -1046,7 +1042,6 @@
"--src",
"tests",
"gm",
- "image",
"--blacklist",
"serialize-8888",
"gm",
@@ -2241,7 +2236,6 @@
"--src",
"tests",
"gm",
- "image",
"--blacklist",
"pdf",
"gm",
@@ -2485,7 +2479,6 @@
"--src",
"tests",
"gm",
- "image",
"--blacklist",
"msaa16",
"gm",
diff --git a/tools/dm_flags.py b/tools/dm_flags.py
index 67052bec2f..beb3085b84 100755
--- a/tools/dm_flags.py
+++ b/tools/dm_flags.py
@@ -80,9 +80,13 @@ def get_args(bot):
args.append('--config')
args.extend(configs)
# Run tests, gms, and image decoding tests everywhere.
# TODO: remove skp from default --src list?
- args.extend('--src tests gm image'.split(' '))
+ if 'GPU' in bot:
+ args.extend('--src tests gm'.split(' '))
+ else:
+ args.extend('--src tests gm image'.split(' '))
if 'GalaxyS' in bot:
args.extend(('--threads', '0'))
@@ -80,9 +80,13 @@ def get_args(bot):
args.append('--config')
args.extend(configs)
- # Run tests, gms, and image decoding tests everywhere.
+ # Run tests and gms everywhere,
+ # and image decoding tests everywhere except GPU bots.
# TODO: remove skp from default --src list?